@@ -1,8 +1,13 @@
+from unittest.case import skipIf
+
 from parameterized import parameterized
 
 from integration.helpers.base_test import BaseTest
+from integration.helpers.resource import current_region_does_not_support
+from integration.config.service_names import CUSTOM_DOMAIN
 
 
+@skipIf(current_region_does_not_support([CUSTOM_DOMAIN]), "CustomDomain is not supported in this testing region")
 class TestHttpApiWithDisableExecuteApiEndpoint(BaseTest):
     @parameterized.expand(
         [
