@@ -3,6 +3,7 @@ import itertools
 import os.path
 import hashlib
 import sys
+import re
 from functools import reduce, cmp_to_key
 
 from samtranslator.translator.translator import Translator, prepare_plugins, make_policy_template_for_function_plugin
@@ -21,7 +22,7 @@ import pytest
 import yaml
 from unittest import TestCase
 from samtranslator.translator.transform import transform
-from mock import Mock, MagicMock, patch
+from unittest.mock import Mock, MagicMock, patch
 
 BASE_PATH = os.path.dirname(__file__)
 INPUT_FOLDER = BASE_PATH + "/input"
@@ -175,11 +176,6 @@ class AbstractTestTranslator(TestCase):
 
         print(json.dumps(output_fragment, indent=2))
 
-        # Only update the deployment Logical Id hash in Py3.
-        if sys.version_info.major >= 3:
-            self._update_logical_id_hash(expected)
-            self._update_logical_id_hash(output_fragment)
-
         self.assertEqual(deep_sort_lists(output_fragment), deep_sort_lists(expected))
 
     def _update_logical_id_hash(self, resources):
@@ -258,6 +254,7 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
     @parameterized.expand(
         itertools.product(
             [
+                "congito_userpool_with_sms_configuration",
                 "cognito_userpool_with_event",
                 "s3_with_condition",
                 "function_with_condition",
@@ -282,6 +279,7 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
                 "function_with_mq_virtual_host",
                 "simpletable",
                 "simpletable_with_sse",
+                "resource_with_invalid_type",
                 "implicit_api",
                 "explicit_api",
                 "api_description",
@@ -327,6 +325,8 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
                 "api_request_model_with_validator",
                 "api_with_stage_tags",
                 "api_with_mode",
+                "api_with_no_properties",
+                "api_with_disable_api_execute_endpoint",
                 "s3",
                 "s3_create_remove",
                 "s3_existing_lambda_notification_configuration",
@@ -376,6 +376,7 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
                 "function_with_global_layers",
                 "function_with_layers",
                 "function_with_many_layers",
+                "function_with_null_events",
                 "function_with_permissions_boundary",
                 "function_with_policy_templates",
                 "function_with_sns_event_source_all_parameters",
@@ -444,6 +445,7 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
                 "state_machine_with_condition_and_events",
                 "state_machine_with_xray_policies",
                 "state_machine_with_xray_role",
+                "state_machine_with_null_events",
                 "function_with_file_system_config",
                 "state_machine_with_permissions_boundary",
                 "version_deletion_policy_precedence",
@@ -456,6 +458,18 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
                 "function_with_auth_mechanism_for_self_managed_kafka",
                 "function_with_vpc_permission_for_self_managed_kafka",
                 "function_with_event_filtering",
+                "api_with_security_definition_and_components",
+                "api_with_security_definition_and_none_components",
+                "api_with_security_definition_and_no_components",
+                "api_http_paths_with_if_condition",
+                "api_http_paths_with_if_condition_no_value_then_case",
+                "api_http_paths_with_if_condition_no_value_else_case",
+                "api_rest_paths_with_if_condition_swagger",
+                "api_rest_paths_with_if_condition_swagger_no_value_then_case",
+                "api_rest_paths_with_if_condition_swagger_no_value_else_case",
+                "api_rest_paths_with_if_condition_openapi",
+                "api_rest_paths_with_if_condition_openapi_no_value_then_case",
+                "api_rest_paths_with_if_condition_openapi_no_value_else_case",
             ],
             [
                 ("aws", "ap-southeast-1"),
@@ -514,6 +528,7 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
                 "http_api_description",
                 "http_api_lambda_auth",
                 "http_api_lambda_auth_full",
+                "http_api_multiple_authorizers",
             ],
             [
                 ("aws", "ap-southeast-1"),
@@ -555,11 +570,6 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
 
         print(json.dumps(output_fragment, indent=2))
 
-        # Only update the deployment Logical Id hash in Py3.
-        if sys.version_info.major >= 3:
-            self._update_logical_id_hash(expected)
-            self._update_logical_id_hash(output_fragment)
-
         self.assertEqual(deep_sort_lists(output_fragment), deep_sort_lists(expected))
 
     @parameterized.expand(
@@ -614,11 +624,6 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
             output_fragment = transform(manifest, parameter_values, mock_policy_loader)
         print(json.dumps(output_fragment, indent=2))
 
-        # Only update the deployment Logical Id hash in Py3.
-        if sys.version_info.major >= 3:
-            self._update_logical_id_hash(expected)
-            self._update_logical_id_hash(output_fragment)
-
         self.assertEqual(deep_sort_lists(output_fragment), deep_sort_lists(expected))
 
     @parameterized.expand(
@@ -686,6 +691,7 @@ def test_transform_invalid_document(testcase):
         transform(manifest, parameter_values, mock_policy_loader)
 
     error_message = get_exception_error_message(e)
+    error_message = re.sub(r"u'([A-Za-z0-9]*)'", r"'\1'", error_message)
 
     assert error_message == expected.get("errorMessage")
 
@@ -931,6 +937,37 @@ class TestTemplateValidation(TestCase):
             translator = Translator({}, sam_parser)
             translator.translate(template, {})
 
+    @patch("boto3.session.Session.region_name", "ap-southeast-1")
+    @patch("botocore.client.ClientEndpointBridge._check_default_region", mock_get_region)
+    def test_validate_translated_no_metadata(self):
+        with open(os.path.join(INPUT_FOLDER, "translate_convert_metadata.yaml"), "r") as f:
+            template = yaml_parse(f.read())
+        with open(os.path.join(OUTPUT_FOLDER, "translate_convert_no_metadata.json"), "r") as f:
+            expected = json.loads(f.read())
+
+        mock_policy_loader = get_policy_mock()
+
+        sam_parser = Parser()
+        translator = Translator(mock_policy_loader, sam_parser)
+        actual = translator.translate(template, {})
+        self.assertEqual(expected, actual)
+
+    @patch("boto3.session.Session.region_name", "ap-southeast-1")
+    @patch("botocore.client.ClientEndpointBridge._check_default_region", mock_get_region)
+    def test_validate_translated_metadata(self):
+        self.maxDiff = None
+        with open(os.path.join(INPUT_FOLDER, "translate_convert_metadata.yaml"), "r") as f:
+            template = yaml_parse(f.read())
+        with open(os.path.join(OUTPUT_FOLDER, "translate_convert_metadata.json"), "r") as f:
+            expected = json.loads(f.read())
+
+        mock_policy_loader = get_policy_mock()
+
+        sam_parser = Parser()
+        translator = Translator(mock_policy_loader, sam_parser)
+        actual = translator.translate(template, {}, passthrough_metadata=True)
+        self.assertEqual(expected, actual)
+
 
 class TestPluginsUsage(TestCase):
     # Tests if plugins are properly injected into the translator
@@ -1040,4 +1077,21 @@ def get_resource_by_type(template, type):
 
 
 def get_exception_error_message(e):
-    return reduce(lambda message, error: message + " " + error.message, e.value.causes, e.value.message)
+    return reduce(
+        lambda message, error: message + " " + error.message,
+        sorted(e.value.causes, key=_exception_sort_key),
+        e.value.message,
+    )
+
+
+def _exception_sort_key(cause):
+    """
+    Returns the key to be used for sorting among other exceptions
+    """
+    if hasattr(cause, "_logical_id"):
+        return cause._logical_id
+    if hasattr(cause, "_event_id"):
+        return cause._event_id
+    if hasattr(cause, "message"):
+        return cause.message
+    return str(cause)
